@@ -1,4 +1,4 @@
-/* $Id: fsd_session.c 20 2011-10-12 16:02:34Z mmamonski $ */
+/* $Id: fsd_session.c 36 2012-01-08 15:37:52Z mmamonski $ */
 /*
  * FedStage DRMAA utilities library
  * Copyright (C) 2006-2008  FedStage Systems
@@ -32,7 +32,7 @@ static char rcsid[]
 #	ifdef __GNUC__
 		__attribute__ ((unused))
 #	endif
-	= "$Id: fsd_session.c 20 2011-10-12 16:02:34Z mmamonski $";
+	= "$Id: fsd_session.c 36 2012-01-08 15:37:52Z mmamonski $";
 #endif
 
 
@@ -408,7 +408,10 @@ fsd_drmaa_session_job_ps(
 	 {
 		job = self->get_job( self, job_id );
 		if( job == NULL )
+		 {
+			fsd_log_info(( "job_ps: recreating job object: %s", job_id ));
 			job = self->new_job( self, job_id );
+		 }
 		fsd_log_debug((" job->last_update_time = %u",  (unsigned int)job->last_update_time));
 		if( time(NULL) - job->last_update_time >= self->cache_job_state
 				|| job->state == DRMAA_PS_UNDETERMINED ) 
@@ -529,8 +532,11 @@ fsd_drmaa_session_wait_for_single_job(
 	 {
 		job = self->get_job( self, job_id );
 		if( job == NULL )
-			fsd_exc_raise_fmt( FSD_DRMAA_ERRNO_INVALID_JOB,
-					"Job '%s' not found in DRMS queue", job_id );
+		 {
+			fsd_log_info(("Job %s is not known to DRMAA. Creating job object.", job_id));
+			job = self->new_job( self, job_id );
+			self->jobs->add( self->jobs, job );
+		 }
 		job->update_status( job );
 		while( !self->destroy_requested  &&  job->state < DRMAA_PS_DONE )
 		 {
