@@ -1,4 +1,4 @@
-/* $Id: job.h 12 2011-04-20 15:20:29Z mmamonski $ */
+/* $Id: job.h 62 2012-01-10 08:58:12Z mmamonski $ */
 /*
  *  FedStage DRMAA for PBS Pro
  *  Copyright (C) 2006-2009  FedStage Systems
@@ -36,13 +36,12 @@ pbsdrmaa_job_new( char *job_id );
 
 struct pbsdrmaa_job_s {
 	fsd_job_t super;
+	time_t missing_time; /* The time when job was seen as missing for the first time */
 
 	void (*
 	update)( fsd_job_t *self, struct batch_status *status );
 };
 
-void
-pbsdrmaa_job_on_missing_standard( fsd_job_t *self );
 
 #endif /* __PBS_DRMAA__JOB_H */
 
