@@ -1,4 +1,4 @@
-/* $Id: log_reader.c 38 2011-10-27 16:25:37Z mmamonski $ */
+/* $Id: log_reader.c 93 2013-07-25 05:38:44Z mmamonski $ */
 /*
  *  FedStage DRMAA for PBS Pro
  *  Copyright (C) 2006-2007  FedStage Systems
@@ -71,9 +71,11 @@ enum pbsdrmaa_event_type
 
 static void pbsdrmaa_read_log();
 
-static void pbsdrmaa_select_file_wait_thread( pbsdrmaa_log_reader_t * self);
+static void pbsdrmaa_select_file( pbsdrmaa_log_reader_t * self);
 
-char *pbsdrmaa_read_line_wait_thread( pbsdrmaa_log_reader_t * self);
+static void pbsdrmaa_close_log( pbsdrmaa_log_reader_t * self);
+
+static void pbsdrmaa_reopen_log( pbsdrmaa_log_reader_t * self);
 
 static time_t pbsdrmaa_parse_log_timestamp(const char *timestamp, char *unixtime_str, size_t size);
 
@@ -140,13 +142,17 @@ pbsdrmaa_log_reader_new( fsd_drmaa_session_t *session )
 		
 		self->session = session;
 
-		self->select_file = pbsdrmaa_select_file_wait_thread;
+		self->select_file = pbsdrmaa_select_file;
 		self->read_log = pbsdrmaa_read_log;	
+		self->close = pbsdrmaa_close_log;
+		self->reopen = pbsdrmaa_reopen_log;
 		
 		self->run_flag = true;
 		self->fhandle = NULL;
 		self->date_changed = true;
 		self->first_open = true;
+		self->log_path = NULL;
+		self->current_offset = 0;
 		
 	}
 	EXCEPT_DEFAULT
@@ -224,6 +230,18 @@ pbsdrmaa_read_log( pbsdrmaa_log_reader_t * self )
 						if ( field_id == PBSDRMAA_FLD_ID_DATE)
 						 {
 							event_timestamp = field_token;
+#ifdef PBS_PBS_PROFESSIONAL
+							/*additional check */
+							TRY
+							{
+							 (void)pbsdrmaa_parse_log_timestamp(event_timestamp, timestamp_unix, sizeof(timestamp_unix));
+							}
+							EXCEPT_DEFAULT
+							{
+								fsd_log_error(("Failed to parse timestamp: %s. Log corrupted?", event_timestamp));
+							}
+							END_TRY
+#endif
 						 }
 						else if ( field_id == PBSDRMAA_FLD_ID_EVENT)
 						 {
@@ -340,7 +358,7 @@ pbsdrmaa_read_log( pbsdrmaa_log_reader_t * self )
 									fsd_log_info(("WT - Job %s killed before entering running state (%d).", job->job_id, job->state));
 									attribs = pbsdrmaa_add_attr(attribs, PBSDRMAA_JOB_STATE, "C");
 									attribs = pbsdrmaa_add_attr(attribs, PBSDRMAA_MTIME, timestamp_unix);
-									attribs = pbsdrmaa_add_attr(attribs, PBSDRMAA_EXIT_STATUS, "-2");
+									attribs = pbsdrmaa_add_attr(attribs, PBSDRMAA_EXIT_STATUS, "-101");
 								 }
 								else
 								 {
@@ -456,8 +474,14 @@ pbsdrmaa_read_log( pbsdrmaa_log_reader_t * self )
 
 
 				fsd_mutex_unlock( &self->session->mutex );
-				
-				usleep(300000); /* 300 ms - consider using inotify - but this would not work with NFS */				
+
+				/* close */
+				self->close(self);
+
+				sleep(((pbsdrmaa_session_t *)self->session)->wait_thread_sleep_time);
+
+				/* and reopen log file */
+				self->reopen(self);
 
 				fsd_mutex_lock( &self->session->mutex );
 
@@ -489,15 +513,15 @@ pbsdrmaa_read_log( pbsdrmaa_log_reader_t * self )
 }
 
 void
-pbsdrmaa_select_file_wait_thread ( pbsdrmaa_log_reader_t * self )
+pbsdrmaa_select_file( pbsdrmaa_log_reader_t * self )
 {
 	pbsdrmaa_session_t *pbssession = (pbsdrmaa_session_t*) self->session;
 	
 	if (self->date_changed)
 	 {
-		char * log_path = NULL;
 		int num_tries = 0;
 		struct tm tm; 
+		char *old_log_path = NULL;
 		
 		fsd_log_enter((""));
 		
@@ -510,17 +534,19 @@ pbsdrmaa_select_file_wait_thread ( pbsdrmaa_log_reader_t * self )
 				
 		#define DRMAA_WAIT_THREAD_MAX_TRIES (12)
 		/* generate new date, close file and open new */
-		log_path = fsd_asprintf("%s/server_logs/%04d%02d%02d", pbssession->pbs_home, tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday);
+		old_log_path = self->log_path;
+
+		self->log_path = fsd_asprintf("%s/server_logs/%04d%02d%02d", pbssession->pbs_home, tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday);
 
 		if(self->fhandle)
 			fclose(self->fhandle);
 
-		fsd_log_info(("Opening log file: %s",log_path));
+		fsd_log_info(("Opening log file: %s",self->log_path));
 				
 	retry:
-		if ((self->fhandle = fopen(log_path,"r")) == NULL && (num_tries > DRMAA_WAIT_THREAD_MAX_TRIES || self->first_open))
+		if ((self->fhandle = fopen(self->log_path,"r")) == NULL && (num_tries > DRMAA_WAIT_THREAD_MAX_TRIES || self->first_open))
 		 {
-			fsd_log_error(("Can't open log file. Verify pbs_home. Running standard wait_thread."));
+			fsd_log_error(("Can't open log file: %s. Verify pbs_home. Running standard wait_thread.", self->log_path));
 			fsd_log_error(("Remember that without keep_completed set the standard wait_thread won't provide information about job exit status"));
 			/*pbssession->super.enable_wait_thread = false;*/ /* run not wait_thread */
 			pbssession->wait_thread_log = false;
@@ -529,14 +555,12 @@ pbsdrmaa_select_file_wait_thread ( pbsdrmaa_log_reader_t * self )
 		 }
 		else if ( self->fhandle == NULL )
 		 { /* Torque seems not to create a new file immediately after the old one is closed */
-			fsd_log_warning(("Can't open log file: %s. Retries count: %d", log_path, num_tries));
+			fsd_log_warning(("Can't open log file: %s. Retries count: %d", self->log_path, num_tries));
 			num_tries++;
 			sleep(2 * num_tries);
 			goto retry;
 		 }
 
-		fsd_free(log_path);
-
 		fsd_log_debug(("Log file opened"));
 
 		if(self->first_open)
@@ -549,9 +573,19 @@ pbsdrmaa_select_file_wait_thread ( pbsdrmaa_log_reader_t * self )
 			 }
 			self->first_open = false;
 		 }
+		else if (old_log_path && strcmp(old_log_path, self->log_path) == 0)
+		 {
+			fsd_log_info(("PBS restarted. Seeking log file %u", (unsigned int)self->current_offset));
+			if(fseek(self->fhandle, self->current_offset, SEEK_SET) == (off_t) -1)
+			 {
+				fsd_exc_raise_fmt(FSD_ERRNO_INTERNAL_ERROR,"fseek error");
+			 }
+		 }
 
 		self->date_changed = false;
 		
+		fsd_free(old_log_path);
+
 		fsd_log_return((""));
 	}	
 }
@@ -652,4 +686,32 @@ pbsdrmaa_get_exec_host_from_accountig(pbsdrmaa_log_reader_t * log_reader, const
 		return exec_host;
 }
 
+void
+pbsdrmaa_close_log( pbsdrmaa_log_reader_t * self )
+{
+
+	self->current_offset = ftello(self->fhandle);
+	
+	fsd_log_debug(("Closing log  file (offset=%d)", (int)self->current_offset));
+
+	fclose(self->fhandle);
+
+	self->fhandle = NULL;
+}
+
+void
+pbsdrmaa_reopen_log( pbsdrmaa_log_reader_t * self )
+{
+	fsd_log_debug(("Reopening log file: %s (offset=%d)", self->log_path, (int)self->current_offset));
+
+	if ((self->fhandle = fopen(self->log_path,"r")) == NULL)
+	 {
+		fsd_exc_raise_fmt(FSD_ERRNO_INTERNAL_ERROR,"Failed to reopen log file");
+	 }
+
+	if(fseek(self->fhandle, self->current_offset, SEEK_SET) == (off_t) -1)
+	 {
+		fsd_exc_raise_fmt(FSD_ERRNO_INTERNAL_ERROR,"fseek error");
+	 }
+}
 
