@@ -1,4 +1,4 @@
-/* $Id: submit.c 37 2011-10-27 16:00:59Z mmamonski $ */
+/* $Id: submit.c 91 2013-03-22 14:08:32Z mmamonski $ */
 /*
  *  FedStage DRMAA for PBS Pro
  *  Copyright (C) 2006-2009  FedStage Systems
@@ -23,11 +23,13 @@
 
 #include <unistd.h>
 #include <string.h>
+#include <stdlib.h>
 
 #include <pbs_ifl.h>
 #include <pbs_error.h>
 
 #include <drmaa_utils/conf.h>
+#include <drmaa_utils/exec.h>
 #include <drmaa_utils/drmaa.h>
 #include <drmaa_utils/drmaa_util.h>
 #include <drmaa_utils/datetime.h>
@@ -45,22 +47,19 @@ static char rcsid[]
 #	ifdef __GNUC__
 		__attribute__ ((unused))
 #	endif
-	= "$Id: submit.c 37 2011-10-27 16:00:59Z mmamonski $";
+	= "$Id: submit.c 91 2013-03-22 14:08:32Z mmamonski $";
 #endif
 
-static void
-pbsdrmaa_submit_destroy( pbsdrmaa_submit_t *self );
+static void pbsdrmaa_submit_destroy( pbsdrmaa_submit_t *self );
 
-static char *
-pbsdrmaa_submit_submit( pbsdrmaa_submit_t *self );
+static char *pbsdrmaa_submit_submit( pbsdrmaa_submit_t *self );
 
-static void
-pbsdrmaa_submit_eval( pbsdrmaa_submit_t *self );
+static void pbsdrmaa_submit_eval( pbsdrmaa_submit_t *self );
 
+static void pbsdrmaa_submit_set( pbsdrmaa_submit_t *self, const char *pbs_attr, char *value, unsigned placeholders );
+
+static struct attrl *pbsdrmaa_submit_filter(struct attrl *pbs_attr);
 
-static void
-pbsdrmaa_submit_set( pbsdrmaa_submit_t *self, const char *pbs_attr,
-		char *value, unsigned placeholders );
 
 static void pbsdrmaa_submit_apply_defaults( pbsdrmaa_submit_t *self );
 static void pbsdrmaa_submit_apply_job_script( pbsdrmaa_submit_t *self );
@@ -100,8 +99,7 @@ pbsdrmaa_submit_new( fsd_drmaa_session_t *session,
 		self->apply_job_resources = pbsdrmaa_submit_apply_job_resources;
 		self->apply_job_environment = pbsdrmaa_submit_apply_job_environment;
 		self->apply_email_notification = pbsdrmaa_submit_apply_email_notification;
-		self->apply_native_specification =
-			pbsdrmaa_submit_apply_native_specification;
+		self->apply_native_specification = pbsdrmaa_submit_apply_native_specification;
 
 		self->pbs_job_attributes = pbsdrmaa_pbs_template_new();
 		self->expand_ph = fsd_expand_drmaa_ph_new( NULL, NULL,
@@ -137,54 +135,77 @@ pbsdrmaa_submit_destroy( pbsdrmaa_submit_t *self )
 char *
 pbsdrmaa_submit_submit( pbsdrmaa_submit_t *self )
 {
-	volatile bool conn_lock = false;
 	struct attrl *volatile pbs_attr = NULL;
 	char *volatile job_id = NULL;
 	TRY
 	 {
-		const fsd_template_t *pbs_tmpl = self->pbs_job_attributes;
-		unsigned i;
+		fsd_template_t *pbs_tmpl = self->pbs_job_attributes;
+		int i;
 
-		for( i = 0;  i < PBSDRMAA_N_PBS_ATTRIBUTES;  i++ )
+		for( i = PBSDRMAA_N_PBS_ATTRIBUTES - 1; i >= 0; i-- ) /* down loop -> start with custom resources */
 		 {
 			const char *name = pbs_tmpl->by_code( pbs_tmpl, i )->name;
-			if( name  &&  name[0] != '!' && pbs_tmpl->get_attr( pbs_tmpl, name ) )
-			 {
-				const char *value;
+			const char *value = pbs_tmpl->get_attr( pbs_tmpl, name );
 
-				value = pbs_tmpl->get_attr( pbs_tmpl, name );
+			if (!value)
+				continue;
+
+			if ( i == PBSDRMAA_ATTR_CUSTOM_RESOURCES)
+			 {
+				char *value_copy = fsd_strdup(value);
+				char *tok_comma_ctx = NULL;
+				char *res_token = NULL;
+				/* matlab:2,simulink:1 */
+
+				for (res_token = strtok_r(value_copy, ";", &tok_comma_ctx); res_token; res_token = strtok_r(NULL, ";", &tok_comma_ctx))
+				 {
+					char *value_p = strstr(res_token, ":");
+
+					if (value_p)
+					 {
+						char *name_p = NULL;
+						*value_p = '\0';
+						value_p++;
+						name_p = fsd_asprintf("Resource_List.%s",res_token);
+						pbs_attr = pbsdrmaa_add_attr( pbs_attr, name_p, value_p );
+						fsd_free(name_p);
+					 }
+					else
+					 {
+						fsd_exc_raise_code( FSD_DRMAA_ERRNO_INVALID_ATTRIBUTE_VALUE );
+					 }
+				 }
+
+				fsd_free(value_copy);
+			 }
+			else if (i == PBSDRMAA_ATTR_NODE_PROPERTIES)
+			 {
+				const char *nodes_value = pbs_tmpl->get_attr( pbs_tmpl, PBSDRMAA_NODES );
+				char *final_value = NULL;
+
+				if (nodes_value)
+				 {
+					final_value = fsd_asprintf("%s:%s",nodes_value, value);
+				 }
+				else
+				 {
+					final_value = fsd_asprintf("1:%s", value);
+				 }
+
+				pbs_tmpl->set_attr( pbs_tmpl, PBSDRMAA_NODES, final_value);
+				fsd_free(final_value);
+			 }
+			else
+			 {
 				pbs_attr = pbsdrmaa_add_attr( pbs_attr, name, value );
 			 }
 		 }
 
-		conn_lock = fsd_mutex_lock( &self->session->drm_connection_mutex );
-retry:
-		job_id = pbs_submit( ((pbsdrmaa_session_t*)self->session)->pbs_conn,
-				(struct attropl*)pbs_attr, self->script_filename,
-				self->destination_queue, NULL );
 
-		fsd_log_info(("pbs_submit(%s, %s) =%s", self->script_filename, self->destination_queue, job_id));
+		pbs_attr = pbsdrmaa_submit_filter(pbs_attr);
+
+		job_id = ((pbsdrmaa_session_t *)self->session)->pbs_connection->submit( ((pbsdrmaa_session_t *)self->session)->pbs_connection, (struct attropl*)pbs_attr, self->script_filename, self->destination_queue);
 
-		if( job_id == NULL )
-		{
-			if (pbs_errno == PBSE_PROTOCOL || pbs_errno == PBSE_EXPIRED)
-			 {
-				pbsdrmaa_session_t *pbsself = (pbsdrmaa_session_t*)self->session;
-				if (pbsself->pbs_conn >= 0 )
-					pbs_disconnect( pbsself->pbs_conn );
-				sleep(1);
-				pbsself->pbs_conn = pbs_connect( pbsself->super.contact );
-				if( pbsself->pbs_conn < 0 )
-					pbsdrmaa_exc_raise_pbs( "pbs_connect" );
-				else
-					goto retry;
-			 }
-			else
-			 {
-				pbsdrmaa_exc_raise_pbs( "pbs_submit" );
-			 }
-		}
-		conn_lock = fsd_mutex_unlock( &self->session->drm_connection_mutex );
 	 }
 	EXCEPT_DEFAULT
 	 {
@@ -193,8 +214,6 @@ retry:
 	 }
 	FINALLY
 	 {
-		if( conn_lock )
-			conn_lock = fsd_mutex_unlock( &self->session->drm_connection_mutex );
 		if( pbs_attr )
 			pbsdrmaa_free_attrl( pbs_attr );
 	 }
@@ -289,12 +308,15 @@ pbsdrmaa_submit_apply_job_script( pbsdrmaa_submit_t *self )
 		script_len = 0;
 		if( wd != NULL )
 			script_len += strlen("cd ") + strlen(wd) + strlen("; ");
-		script_len += strlen("exec ") + strlen(executable);
+		script_len += strlen("touch ") + strlen(((pbsdrmaa_session_t *)self->session)->job_exit_status_file_prefix) + strlen("/$PBS_JOBID.started;");
+		script_len += strlen(executable);
 		if( argv != NULL )
 			for( i = argv;  *i != NULL;  i++ )
 				script_len += 3+strlen(*i);
 		if( input_path != NULL )
 			script_len += strlen(" <") + strlen(input_path);
+
+		script_len += strlen(";EXIT_CODE=$?; echo $EXIT_CODE >") + strlen(((pbsdrmaa_session_t *)self->session)->job_exit_status_file_prefix) + strlen("/$PBS_JOBID.exitcode; exit $EXIT_CODE");
 	 }
 
 	fsd_calloc( script, script_len+1, char );
@@ -304,12 +326,16 @@ pbsdrmaa_submit_apply_job_script( pbsdrmaa_submit_t *self )
 		s = script;
 		if( wd != NULL )
 			s += sprintf( s, "cd %s; ", wd );
-		s += sprintf( s, "exec %s", executable );
+		s += sprintf( s, "touch %s/$PBS_JOBID.started;", ((pbsdrmaa_session_t *)self->session)->job_exit_status_file_prefix);
+		s += sprintf( s, "%s", executable );
 		if( argv != NULL )
 			for( i = argv;  *i != NULL;  i++ )
 				s += sprintf( s, " '%s'", *i );
 		if( input_path != NULL )
 			s += sprintf( s, " <%s", input_path );
+
+		s += sprintf( s, ";EXIT_CODE=$?; echo $EXIT_CODE >%s/$PBS_JOBID.exitcode; exit $EXIT_CODE", ((pbsdrmaa_session_t *)self->session)->job_exit_status_file_prefix);
+
 		fsd_assert( s == script+script_len );
 	 }
 
@@ -380,7 +406,6 @@ pbsdrmaa_submit_apply_job_files( pbsdrmaa_submit_t *self )
 	const fsd_template_t *jt = self->job_template;
 	fsd_template_t *pbs_attr = self->pbs_job_attributes;
 	const char *join_files;
-	bool b_join_files;
 	int i;
 
 	for( i = 0;  i < 2;  i++ )
@@ -410,8 +435,15 @@ pbsdrmaa_submit_apply_job_files( pbsdrmaa_submit_t *self )
 	 }
 
 	join_files = jt->get_attr( jt, DRMAA_JOIN_FILES );
-	b_join_files = join_files != NULL  &&  !strcmp(join_files,"1");
-	pbs_attr->set_attr( pbs_attr, PBSDRMAA_JOIN_FILES, (b_join_files ? "y" : "n") ); 
+	if (join_files != NULL && strcmp(join_files, "y") == 0)
+	  {
+		pbs_attr->set_attr( pbs_attr, PBSDRMAA_JOIN_FILES, "oe" ); 
+	  }
+        else if (join_files != NULL && strcmp(join_files, "n") != 0)
+          {
+		fsd_exc_raise_fmt( FSD_ERRNO_INVALID_VALUE, "invalid value of %s attribute. Should be 'y' or 'n'.",
+					DRMAA_JOIN_FILES );
+          }
 }
 
 
@@ -441,6 +473,8 @@ pbsdrmaa_submit_apply_job_resources( pbsdrmaa_submit_t *self )
 		pbs_attr->set_attr( pbs_attr, "Resource_List.walltime", walltime_limit );
 }
 
+
+
 void
 pbsdrmaa_submit_apply_job_environment( pbsdrmaa_submit_t *self )
 {
@@ -464,13 +498,14 @@ pbsdrmaa_submit_apply_job_environment( pbsdrmaa_submit_t *self )
 	}
 
 	if (env_v)
-	{
+	 {
 		ii = 0;
-		while (env_v[ii]) {
+		while (env_v[ii])
+		 {
 			len += strlen(env_v[ii]) + 1;
 			ii++;
-		}
-	}
+		 }
+	 }
 	
 	len+= strlen("PBS_O_WORKDIR=") + strlen(wd);
 
@@ -524,7 +559,26 @@ pbsdrmaa_submit_apply_job_category( pbsdrmaa_submit_t *self )
 		self->apply_native_specification( self, category_spec );
 }
 
-static void parse_resources(fsd_template_t *pbs_attr,const char *resources)
+static const char *get_job_env(pbsdrmaa_submit_t *self, const char *env_name)
+{
+	const fsd_template_t *jt = self->job_template;
+	const char *const *env_v = jt->get_v_attr( jt, DRMAA_V_ENV);
+	int ii = 0;
+
+	while (env_v[ii])
+	 {
+		char *eq_p = strstr(env_v[ii], "=");
+
+		if ((eq_p) && (strncmp(env_v[ii], env_name, eq_p - env_v[ii]) == 0))
+				return ++eq_p;
+
+		ii++;
+	 }
+
+	return NULL;
+}
+
+static void parse_resources(pbsdrmaa_submit_t *self, fsd_template_t *pbs_attr,const char *resources)
 {
 	char * volatile name = NULL;
 	char *arg = NULL;
@@ -543,7 +597,10 @@ static void parse_resources(fsd_template_t *pbs_attr,const char *resources)
 				*psep = '\0';
 				name = fsd_asprintf("Resource_List.%s", arg);
 				value = ++psep;
-				pbs_attr->set_attr( pbs_attr, name , value );
+				if (value[0] == '$' && get_job_env(self, value + 1))
+					pbs_attr->set_attr( pbs_attr, name , get_job_env(self, value + 1) ); /*get value from job env variable */
+				else
+					pbs_attr->set_attr( pbs_attr, name , value );
 				fsd_free(name);
 				name = NULL;
 			}
@@ -593,7 +650,7 @@ void
 pbsdrmaa_submit_apply_native_specification( pbsdrmaa_submit_t *self,
 		const char *native_specification )
 {
-        fsd_log_enter(( "({native_specification=%s})", native_specification ));
+	fsd_log_enter(( "({native_specification=%s})", native_specification ));
 
 	if( native_specification == NULL )
 		native_specification = self->job_template->get_attr(
@@ -602,7 +659,6 @@ pbsdrmaa_submit_apply_native_specification( pbsdrmaa_submit_t *self,
 		return;
 
 	{
-		fsd_iter_t * volatile args_list = fsd_iter_new(NULL, 0);
 		fsd_template_t *pbs_attr = self->pbs_job_attributes;
 		char *arg = NULL;
 		volatile char * native_spec_copy = fsd_strdup(native_specification);
@@ -611,7 +667,7 @@ pbsdrmaa_submit_apply_native_specification( pbsdrmaa_submit_t *self,
 
 		TRY
 		  {
-			for (arg = strtok_r(native_spec_copy, " \t", &ctxt); arg; arg = strtok_r(NULL, " \t",&ctxt) ) {
+			for (arg = strtok_r((char *)native_spec_copy, " \t", &ctxt); arg; arg = strtok_r(NULL, " \t",&ctxt) ) {
 				if (!opt)
 				  {
 					if ( (arg[0] != '-') || (strlen(arg) != 2) )
@@ -693,7 +749,7 @@ pbsdrmaa_submit_apply_native_specification( pbsdrmaa_submit_t *self,
 							pbs_attr->set_attr( pbs_attr, "Mail_Users" , arg );
 							break;
 						case 'l' :
-							parse_resources(pbs_attr, arg);
+							parse_resources( self, pbs_attr, arg);
 							break;							
 						default :
 							
@@ -709,17 +765,112 @@ pbsdrmaa_submit_apply_native_specification( pbsdrmaa_submit_t *self,
 				fsd_exc_raise_fmt(FSD_DRMAA_ERRNO_INVALID_ATTRIBUTE_VALUE,
 						"Invalid native specification: %s",
 						native_specification);
-
 		 }
 		FINALLY
 		 {
 #ifndef PBS_PROFESSIONAL
 			pbs_attr->set_attr( pbs_attr, "submit_args", native_specification);
 #endif
-			args_list->destroy(args_list);
-			fsd_free(native_spec_copy);
+			fsd_free((char *)native_spec_copy);
 		 }
 		END_TRY
 	}
 }
 
+struct attrl *
+pbsdrmaa_submit_filter(struct attrl *pbs_attr)
+{
+	fsd_log_enter(( "({pbs_attr=%p})", (void*)pbs_attr));
+
+	if (getenv(PBSDRMAA_SUBMIT_FILTER_ENV) == NULL) 
+	  {
+		return pbs_attr;
+	  } 
+	else 
+	  {
+		struct attrl *ii = NULL;
+		char *empty_args[] = { NULL };
+		int exit_status = -1;
+		const char *submit_filter = getenv(PBSDRMAA_SUBMIT_FILTER_ENV);
+		char *stdin_buf = NULL;
+		int stdin_size = 0;
+		char *stdout_buf = NULL;
+		char *stderr_buf = NULL;
+		char *output_line = NULL;
+		char *ctx = NULL;
+
+		fsd_log_debug(("Executing filter script: %s", submit_filter));
+		
+		
+		for (ii = pbs_attr; ii; ii = ii->next) 
+		  {
+			stdin_size += strlen(ii->name) + strlen(ii->value) + 2 /* '=' and '\n' */;
+			if (ii->resource)
+			  {
+				stdin_size += strlen(ii->resource) +  1; /* '.' */
+			  }
+		  }
+
+		stdin_size+=1; /* '\0' */
+
+		stdin_buf = fsd_calloc(stdin_buf, stdin_size, char);
+		stdin_buf[0] = '\0';
+
+		for (ii = pbs_attr; ii; ii = ii->next) 
+		  {
+			strcat(stdin_buf, ii->name);
+			if (ii->resource)
+			  {
+				strcat(stdin_buf, ".");
+				strcat(stdin_buf, ii->resource);
+			  }
+			strcat(stdin_buf, "=");
+			strcat(stdin_buf, ii->value);
+			strcat(stdin_buf, "\n");
+		  }
+		
+		exit_status = fsd_exec_sync(submit_filter, empty_args, stdin_buf, &stdout_buf, &stderr_buf);
+    fsd_free(stdin_buf);
+
+		if (exit_status != 0)
+		  {
+			fsd_log_error(("Filter script %s exited with non-zero code: %d", submit_filter, exit_status));
+			fsd_exc_raise_fmt(FSD_DRMAA_ERRNO_INVALID_ATTRIBUTE_VALUE, "Submit filter script failed (code: %d, message: %s)", exit_status, stderr_buf);
+		  }
+		
+		fsd_log_debug(("Submit filter exit_status=%d, stderr=%s", exit_status, stderr_buf));
+
+		pbsdrmaa_free_attrl(pbs_attr);
+		pbs_attr = NULL;
+
+		/* exit_status == 0 */
+		for (output_line = strtok_r(stdout_buf, "\n", &ctx);  output_line ; output_line = strtok_r(NULL, "\n", &ctx))
+		  {
+			char *attr_name = NULL;
+			char *attr_value = NULL;
+
+			attr_value = strstr(output_line,"=");
+			attr_name = output_line;
+
+			if (!attr_value)
+			  {
+				fsd_exc_raise_fmt(FSD_DRMAA_ERRNO_INVALID_ATTRIBUTE_FORMAT, "Invalid output line of submit filter: %s", output_line);
+			  }
+			else
+			  {
+				*attr_value = '\0';
+				attr_value++; 
+			  }
+			
+
+			pbs_attr = pbsdrmaa_add_attr( pbs_attr, attr_name, attr_value );
+      }
+
+	  fsd_free(stdout_buf);
+    fsd_free(stderr_buf);	
+
+		return pbs_attr;
+	  }
+
+}
+
